GeneEnrich
==========

Installation and Usage
----------------------

Manual installation
~~~~~~~~~~~~~~~~~~~

The recommended installation is as follows.:

install GeneEnrich:

.. code-block:: bash

   (GeneEnrich) $ pip install -e GeneEnrich
   (GeneEnrich) $ conda install micromamba
   (GeneEnrich) $ cd GeneEnrich
   (GeneEnrich) $ micromamba install -n GeneEnrich --file conda_pkgs.txt
